@@ -66,7 +66,7 @@ def server_version(host, port):
         logging.getLogger(__name__).debug(repr(result))
         return result
     except (Fault, socket.error):
-        raise
+        return None
 
 
 def login(username, password, host, port, database):
